@@ -1,10 +1,12 @@
 from .base_filter import Filter
 from .binarize import BinarizeFilter
 from .canny import CannyFilter
+from .compress import CompressFilter
 from .denoise import DenoiseFilter
 from .dilate import DilateFilter
 from .gaussian_blur import GaussianBlurFilter
 from .grayscale import GrayscaleFilter
+from .median_blur import MedianBlurFilter
+from .morphological_close import MorphologicalCloseFilter
 from .perspective_wrapper import PerspectiveWrapperFilter
 from .resize import ResizeFilter
-from .thresholds import ThresholdsFilter
